@@ -1,8 +1,8 @@
 #' Creates an object of class \code{jointdata}
 #' 
-#' This function creates an object of class \code{jointdata}. This is an object 
-#' with information on at least one of, longitudinal data or survival data. 
-#' Moreover, it can also have data on baseline covariates.
+#' @description This function creates an object of class \code{jointdata}. This
+#'   is an object with information on at least one of, longitudinal data or
+#'   survival data. Moreover, it can also have data on baseline covariates.
 #' 
 #' @param longitudinal a data frame or matrix in the unbalanced format (one row 
 #'   per observation), with subject identification, time of measurements, and 
@@ -43,7 +43,6 @@
 #' @export
 #' 
 #' @examples
-#' 
 #' data(heart.valve)
 #' heart.surv <- UniqueVariables(heart.valve,
 #'                               var.col = c("fuyrs", "status"), 
@@ -113,7 +112,7 @@ jointdata <- function(longitudinal = NA, survival = NA, baseline = NA, id.col =
       stop("ID column does not exist in survival object")
     }
     ss <- unique(survival[[id.col]])
-    if (sum(order(patid) != order(ss)) > 0) {
+    if (sum(sort(patid) != sort(ss)) > 0) {
       stop("Number of subjects different in the longitudinal and survival data frames")
     }
     if (length(ss) != dim(survival)[1]) {
@@ -124,7 +123,7 @@ jointdata <- function(longitudinal = NA, survival = NA, baseline = NA, id.col =
         stop("ID column does not exist in baseline object")
       }
       bb <- unique(baseline[[id.col]])
-      if (sum(order(patid) != order(bb)) > 0) {
+      if (sum(sort(patid) != sort(bb)) > 0) {
         stop("Number of subjects different in the longitudinal and covariates data frame")
       }
       if (length(bb) != dim(baseline)[1]) {
